@@ -72,7 +72,7 @@ class SLRParser:
             item_len = len(J)
 
             for head, bodies in J.copy().items():
-                for body in bodies:
+                for body in bodies.copy():
                     if '.' in body[:-1]:
                         symbol_after_dot = body[body.index('.') + 1]
 
@@ -108,8 +108,10 @@ class SLRParser:
 
             for I in C.copy():
                 for X in G_prime.symbols:
-                    if self.GOTO(I, X) and self.GOTO(I, X) not in C:
-                        C.append(self.GOTO(I, X))
+                    goto = self.GOTO(I, X)
+
+                    if goto and goto not in C:
+                        C.append(goto)
 
             if item_len == len(C):
                 return C
@@ -156,7 +158,7 @@ class SLRParser:
 
     def print_info(self):
         def fprint(text, variable):
-            print(f'{text:>13}: {", ".join(variable)}')
+            print(f'{text:>12}: {", ".join(variable)}')
 
         def print_line():
             print(f'+{("-" * width + "+") * (len(list(self.G_prime.symbols) + ["$"]))}')
